@@ -96,7 +96,7 @@ func TestHandler_GetNVMLVersion(t *testing.T) {
 			}
 
 			// Call the method being tested
-			got, err := h.GetNVMLVersion(context.Background(), nil, nil...)
+			got, err := h.GetNVMLVersion(t.Context(), nil, nil...)
 
 			// Check for error match
 			if (err != nil) != tt.wantErr {
@@ -161,7 +161,7 @@ func TestHandler_GetDriverVersion(t *testing.T) {
 			}
 
 			// Call the method being tested
-			got, err := h.GetDriverVersion(context.Background(), nil, nil...)
+			got, err := h.GetDriverVersion(t.Context(), nil, nil...)
 
 			// Check for error match
 			if (err != nil) != tt.wantErr {
@@ -302,7 +302,7 @@ func TestHandler_DeviceDiscovery(t *testing.T) {
 				deviceCache:                 make(map[string]nvml.Device),
 			}
 
-			got, err := h.DeviceDiscovery(context.Background(), nil, nil...)
+			got, err := h.DeviceDiscovery(t.Context(), nil, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.DeviceDiscovery() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -365,7 +365,7 @@ func TestHandler_GetDeviceCount(t *testing.T) {
 			}
 
 			// Call the method being tested
-			got, err := h.GetDeviceCount(context.Background(), nil, nil...)
+			got, err := h.GetDeviceCount(t.Context(), nil, nil...)
 
 			// Check for error match
 			if (err != nil) != tt.wantErr {
@@ -501,7 +501,7 @@ func TestHandler_GetDeviceTemperature(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDeviceTemperature(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDeviceTemperature(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDeviceTemperature() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -634,7 +634,7 @@ func TestHandler_GetDeviceSerial(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDeviceSerial(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDeviceSerial(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDeviceSerial() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -767,7 +767,7 @@ func TestHandler_GetDeviceFanSpeed(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDeviceFanSpeed(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDeviceFanSpeed(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDeviceFanSpeed() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -900,7 +900,7 @@ func TestHandler_GetDevicePerfState(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDevicePerfState(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDevicePerfState(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDevicePerfState() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -1033,7 +1033,7 @@ func TestHandler_GetDeviceEnergyConsumption(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDeviceEnergyConsumption(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDeviceEnergyConsumption(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDeviceEnergyConsumption() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -1166,7 +1166,7 @@ func TestHandler_GetDevicePowerLimit(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDevicePowerLimit(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDevicePowerLimit(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDevicePowerLimit() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -1299,7 +1299,7 @@ func TestHandler_GetDevicePowerUsage(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDevicePowerUsage(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDevicePowerUsage(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDevicePowerUsage() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -1444,7 +1444,7 @@ func TestHandler_GetBAR1MemoryInfo(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetBAR1MemoryInfo(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetBAR1MemoryInfo(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetBAR1MemoryInfo() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -1626,7 +1626,7 @@ func TestHandler_GetFBMemoryInfo(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetFBMemoryInfo(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetFBMemoryInfo(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetFBMemoryInfo() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -1807,7 +1807,7 @@ func TestHandler_GetMemoryErrors(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetMemoryErrors(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetMemoryErrors(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetMemoryErrors() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -1988,7 +1988,7 @@ func TestHandler_GetRegistryErrors(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetRegisterErrors(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetRegisterErrors(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetRegisterErrors() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -2154,7 +2154,7 @@ func TestHandler_GetPCIeThroughput(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetPCIeThroughput(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetPCIeThroughput(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetPCIeThroughput() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -2291,7 +2291,7 @@ func TestHandler_GetEncoderStats(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetEncoderStats(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetEncoderStats(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetEncoderStats() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -2426,7 +2426,7 @@ func TestHandler_GetVideoFrequency(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetVideoFrequency(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetVideoFrequency(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetVideoFrequency() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -2561,7 +2561,7 @@ func TestHandler_GetGraphicsFrequency(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetGraphicsFrequency(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetGraphicsFrequency(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetGraphicsFrequency() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -2696,7 +2696,7 @@ func TestHandler_GetSMFrequency(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetSMFrequency(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetSMFrequency(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetSMFrequency() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -2831,7 +2831,7 @@ func TestHandler_GetMemoryFrequency(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetMemoryFrequency(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetMemoryFrequency(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetMemoryFrequency() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -2964,7 +2964,7 @@ func TestHandler_GetEncoderUtilization(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetEncoderUtilization(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetEncoderUtilization(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetEncoderUtilization() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -3097,7 +3097,7 @@ func TestHandler_GetDecoderUtilization(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDecoderUtilization(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDecoderUtilization(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetDecoderUtilization() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -3230,7 +3230,7 @@ func TestHandler_GetDeviceUtilisation(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetDeviceUtilisation(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetDeviceUtilisation(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetUtilizationRates() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -3363,7 +3363,7 @@ func TestHandler_GetECCMode(t *testing.T) {
 				deviceCache:    make(map[string]nvml.Device),
 			}
 
-			got, err := h.GetECCMode(context.Background(), tt.args.metricParams, nil...)
+			got, err := h.GetECCMode(t.Context(), tt.args.metricParams, nil...)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Handler.GetECCMode() error = %v, wantErr %v", err, tt.wantErr)
 			}
@@ -3443,7 +3443,7 @@ func TestWithJSONResponse(t *testing.T) {
 
 					return tt.args.value, nil
 				},
-			)(context.Background(), nil)
+			)(t.Context(), nil)
 
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("WithJSONResponse() error = %v, wantErr %v", err, tt.wantErr)
